aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/platforms/MSP430
diff options
context:
space:
mode:
authorgdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2011-12-31 10:07:43 +0000
committergdisirio <gdisirio@35acf78f-673a-0410-8e92-d51de3d6d3f4>2011-12-31 10:07:43 +0000
commitc397738010966f85c7ae841e21d74790ac49611c (patch)
tree71fc62ea0e2f86481586f51dbe55ffe691b4b363 /os/hal/platforms/MSP430
parent72266f8b591c6e7857f4578ba753eeea7222ac6b (diff)
downloadChibiOS-c397738010966f85c7ae841e21d74790ac49611c.tar.gz
ChibiOS-c397738010966f85c7ae841e21d74790ac49611c.tar.bz2
ChibiOS-c397738010966f85c7ae841e21d74790ac49611c.zip
Changes to palSetGroupMode(), various adjustments to the PAL driver.
git-svn-id: svn://svn.code.sf.net/p/chibios/svn/trunk@3695 35acf78f-673a-0410-8e92-d51de3d6d3f4
Diffstat (limited to 'os/hal/platforms/MSP430')
-rw-r--r--os/hal/platforms/MSP430/pal_lld.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/os/hal/platforms/MSP430/pal_lld.h b/os/hal/platforms/MSP430/pal_lld.h
index 282ed4e75..97e7795d5 100644
--- a/os/hal/platforms/MSP430/pal_lld.h
+++ b/os/hal/platforms/MSP430/pal_lld.h
@@ -231,7 +231,7 @@ typedef msp430_ioport_t *ioportid_t;
* @details This function is implemented by reading the PxIN register, the
* implementation has no side effects.
*
- * @param[in] port the port identifier
+ * @param[in] port port identifier
* @return The port bits.
*
* @notapi
@@ -243,7 +243,7 @@ typedef msp430_ioport_t *ioportid_t;
* @details This function is implemented by reading the PxOUT register, the
* implementation has no side effects.
*
- * @param[in] port the port identifier
+ * @param[in] port port identifier
* @return The latched logical states.
*
* @notapi
@@ -255,8 +255,8 @@ typedef msp430_ioport_t *ioportid_t;
* @details This function is implemented by writing the PxOUT register, the
* implementation has no side effects.
*
- * @param[in] port the port identifier
- * @param[in] bits the bits to be written on the specified port
+ * @param[in] port port identifier
+ * @param[in] bits bits to be written on the specified port
*
* @notapi
*/
@@ -271,14 +271,15 @@ typedef msp430_ioport_t *ioportid_t;
* @note This function does not alter the @p PxSEL registers. Alternate
* functions setup must be handled by device-specific code.
*
* @param[in] port the port identifier
* @param[in] mask the group mask
* @param[in] mode the mode
*
* @notapi
*/
-#define pal_lld_setgroupmode(port, mask, mode) \
- _pal_lld_setgroupmode(port, mask, mode)
+#define pal_lld_setgroupmode(port, mask, offset, mode) \
+ _pal_lld_setgroupmode(port, mask << offset, mode)
extern const PALConfig pal_default_config;
@@ -271,14 +271,15 @@ typedef msp430_ioport_t *ioportid_t;
* functions setup must be handled by device-specific code.
*
- * @param[in] port the port identifier
- * @param[in] mask the group mask
- * @param[in] mode the mode
+ * @param[in] port port identifier
+ * @param[in] mask group mask
+ * @param[in] offset group bit offset within the port
+ * @param[in] mode group mode
*
* @notapi